@@ -338,7 +338,8 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
                              fig_wi_he=False, fig_lbrt=False,
                              ref_vert_lines=True,
                              end_max_values=True,
-                             node_supports=True, ax=False):
+                             node_supports=True, ax=False,
+                             alt_model_plot=1):
     """Display section forces diagram for 2d beam column model.
 
     This function plots a section forces diagram for 2d beam column elements
@@ -382,6 +383,11 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
 
         ax: the axes object.
 
+        alt_model_plot (int): 1 - for using the plot_model command,  2 - for using
+            simplified model plotting. Other integer - for no model plotting.
+            In this case the model can be plotted outside this command
+            using the axes (ax) object. Default is 1.
+
     Usage:
         See example: demo_portal_frame.py
     """
@@ -397,9 +403,12 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
             fleft, fbottom, fright, ftop = fig_lbrt
             fig.subplots_adjust(left=fleft, bottom=fbottom, right=fright, top=ftop)
 
-    ax = model.plot_model(node_labels=0, element_labels=0,
-                          fmt_model=fmt_model_secforce,
-                          node_supports=False, ax=ax)
+    if alt_model_plot == 1:
+        ax = model.plot_model(node_labels=0, element_labels=0,
+                              fmt_model=fmt_model_secforce,
+                              node_supports=False, ax=ax)
+    else:
+        pass
 
     maxVal, minVal = -np.inf, np.inf
     ele_tags = ops.getEleTags()
@@ -532,7 +541,8 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
                              fmt_secforce2=fmt_secforce2,
                              ref_vert_lines=True,
                              end_max_values=True,
-                             dir_plt=0, ax=False):
+                             dir_plt=0, ax=False,
+                             alt_model_plot=1):
     """Display section forces diagram of a 3d beam column model.
 
     This function plots section forces diagrams for 3d beam column elements
@@ -544,10 +554,6 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
             'Vy' or 'Vz' - shear force, 'My' or 'Mz' - bending moments,
             'T' - torsional moment.
 
-        Ew (dict): Ew Python dictionary contains information on non-zero
-            element loads, therfore each item of the Python dictionary
-            is in the form: 'ele_tag: ['-beamUniform', Wy, Wz, Wx]'.
-
         sfac (float): scale factor by wich the values of section forces are
             multiplied.
 
@@ -567,6 +573,13 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
             1 - in the y-axis (default for N, Vy, T, Mz)
             2 - in the z-axis (default for Vz, My)
 
+        ax: Optional axis to plot to.
+
+        alt_model_plot (int): 1 - for using the plot_model command,  2 - for using
+            simplified model plotting. Other integer - for no model plotting.
+            In this case the model can be plotted outside this command
+            using the axes (ax) object. Default is 1.
+
     Returns:
         minVal (float): the minimum overall value of the section force.
 
@@ -586,15 +599,20 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
     maxVal, minVal = -np.inf, np.inf
     ele_tags = ops.getEleTags()
 
-    azim, elev = az_el
-    fig_wi, fig_he = fig_wi_he
-    fleft, fbottom, fright, ftop = fig_lbrt
+    # If supplied axis can be plotted to
+    if hasattr(ax, "name") and (ax.name == "3d"):
+        pass
+    else:
+        azim, elev = az_el
+        fig_wi, fig_he = fig_wi_he
+        fleft, fbottom, fright, ftop = fig_lbrt
 
-    fig = plt.figure(figsize=(fig_wi/2.54, fig_he/2.54))
-    fig.subplots_adjust(left=.08, bottom=.08, right=.985, top=.94)
+        fig = plt.figure(figsize=(fig_wi / 2.54, fig_he / 2.54))
+        fig.subplots_adjust(left=0.08, bottom=0.08, right=0.985, top=0.94)
 
-    ax = fig.add_subplot(111, projection=Axes3D.name)
-    # ax.axis('equal')
+        ax = fig.add_subplot(111, projection=Axes3D.name)
+
+        ax.view_init(azim=azim, elev=elev)
 
     ax.set_xlabel('X')
     ax.set_ylabel('Y')
@@ -602,9 +620,20 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
 
     ax.view_init(azim=azim, elev=elev)
 
-    ax = model.plot_model(node_labels=0, element_labels=0,
-                          fmt_model=fmt_model_secforce,
-                          node_supports=False, ax=ax)
+    if alt_model_plot == 1:
+        ax = model.plot_model(node_labels=0, element_labels=0,
+                              fmt_model=fmt_model_secforce,
+                              node_supports=False, ax=ax)
+    elif alt_model_plot == 2:
+        # element
+        plt.plot(ex, ey, ez, "k-",
+                 solid_capstyle="round",
+                 solid_joinstyle="round",
+                 dash_capstyle="butt",
+                 dash_joinstyle="round")
+    else:
+        pass
+
 
     Ew = model.get_Ew_data_from_ops_domain_3d()
 
